@@ -2,6 +2,14 @@ OC.L10N.register(
     "deck",
     {
     "Deck" : "Deck",
+    "The file was uploaded" : "El archivo fue cargado",
+    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo cargado excede el valor especificado de la directiva MAX_FILE_SIZE en la forma de HTML",
+    "The file was only partially uploaded" : "El archivo sólo fue cargado parcialmente",
+    "No file was uploaded" : "No se cargó el archivo",
+    "Missing a temporary folder" : "Falta una carpeta temporal",
+    "Could not write file to disk" : "No fue posible escribir a disco",
+    "A PHP extension stopped the file upload" : "Una extensión de PHP detuvo la carga del archivo",
     "The card \"%s\" on \"%s\" has reached its due date." : "La tarjeta \"%s\" en \"%s\" ha alacanzado su fecha de entrega",
     "The board \"%s\" has been shared with you by %s." : "El tablero \"%s\" ha sido compartido contigo por %s.",
     "%s on %s" : "%s en %s",
@@ -11,14 +19,7 @@ OC.L10N.register(
     "Later" : "Después",
     "To Do" : "Por hacer",
     "Done" : "Terminado",
-    "The file was uploaded" : "El archivo fue cargado",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo cargado excede el valor especificado de la directiva MAX_FILE_SIZE en la forma de HTML",
-    "The file was only partially uploaded" : "El archivo sólo fue cargado parcialmente",
-    "No file was uploaded" : "No se cargó el archivo",
-    "Missing a temporary folder" : "Falta una carpeta temporal",
-    "Could not write file to disk" : "No fue posible escribir a disco",
-    "A PHP extension stopped the file upload" : "Una extensión de PHP detuvo la carga del archivo",
+    "File" : "Archivo",
     "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
     "Cancel" : "Cancelar",
     "File already exists" : "El archivo ya existe",
@@ -39,13 +40,13 @@ OC.L10N.register(
     "Edit" : "Editar",
     "Members" : "Miembros",
     "Download" : "Descargar",
-    "Comments" : "Comentarios",
     "Modified" : "Modificado",
     "Created" : "Creado",
+    "Comments" : "Comentarios",
     "Save" : "Guardar",
+    "Created:" : "Creado:",
     "Reply" : "Responder",
     "Update" : "Actualizar",
-    "Created:" : "Creado:",
     "Description" : "Descripción",
     "Formatting help" : "Ayuda de formato",
     "Remove due date" : "Eliminar fecha de expiración",
@@ -64,10 +65,11 @@ OC.L10N.register(
     "No notifications" : "No hay notificaciones",
     "Delete board" : "Borrar tableros",
     "Advanced options" : "Opciones avanzadas",
-    "Today" : "Hoy",
-    "Tomorrow" : "Mañana",
-    "Close" : "Cerrar",
+    "Export" : "Exportar",
+    "Due date" : "Fecha de vencimiento",
     "Share" : "Compartir",
-    "Personal" : "Personal"
+    "Personal" : "Personal",
+    "Today" : "Hoy",
+    "Tomorrow" : "Mañana"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
