@@ -2,6 +2,10 @@ OC.L10N.register(
     "deck",
     {
     "Deck" : "Deck",
+    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo cargado excede el valor especificado de la directiva MAX_FILE_SIZE en la forma de HTML",
+    "No file was uploaded" : "No se cargó el archivo",
+    "Missing a temporary folder" : "Falta una carpeta temporal",
     "The card \"%s\" on \"%s\" has reached its due date." : "La tarjeta \"%s\" en \"%s\" ha alacanzado su fecha de entrega",
     "The board \"%s\" has been shared with you by %s." : "El tablero \"%s\" ha sido compartido contigo por %s.",
     "%s on %s" : "%s en %s",
@@ -11,10 +15,7 @@ OC.L10N.register(
     "Later" : "Después",
     "copy" : "copiar",
     "Done" : "Terminado",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo cargado excede el valor especificado de la directiva MAX_FILE_SIZE en la forma de HTML",
-    "No file was uploaded" : "No se cargó el archivo",
-    "Missing a temporary folder" : "Falta una carpeta temporal",
+    "File" : "Archivo",
     "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
     "Cancel" : "Cancelar",
     "File already exists" : "El archivo ya existe",
@@ -36,13 +37,13 @@ OC.L10N.register(
     "Edit" : "Editar",
     "Members" : "Miembros",
     "Download" : "Descargar",
-    "Comments" : "Comentarios",
     "Modified" : "Modificado",
     "Created" : "Creado",
+    "Comments" : "Comentarios",
     "Save" : "Guardar",
+    "Created:" : "Creado:",
     "Reply" : "Responder",
     "Update" : "Actualizar",
-    "Created:" : "Creado:",
     "Description" : "Descripción",
     "Formatting help" : "Ayuda de formato",
     "Remove due date" : "Eliminar fecha de expiración",
@@ -61,10 +62,12 @@ OC.L10N.register(
     "No notifications" : "No hay notificaciones",
     "Delete board" : "Borrar tableros",
     "Advanced options" : "Opciones avanzadas",
-    "Today" : "Hoy",
-    "Tomorrow" : "Mañana",
+    "Export" : "Exportar",
     "Close" : "Cerrar",
+    "Due date" : "Fecha de vencimiento",
     "Share" : "Compartir",
-    "Personal" : "Personal"
+    "Personal" : "Personal",
+    "Today" : "Hoy",
+    "Tomorrow" : "Mañana"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
