@@ -17,12 +17,35 @@ OC.L10N.register(
     "{user} has archived the board {before}" : "{user} on {before} tahvli arhiveerinud",
     "You have unarchived the board {board}" : "Sa oled „{board}“ tahvli arhiivist eemaldanud",
     "{user} has unarchived the board {before}" : "{user} on „{before}“ tahvli arhiivist eemaldanud",
+    "{user} has created a new list {stack} on board {board}" : "{user} on „{board}“ tahvlil koostanud uue loendi „{stack}“ ",
     "You have renamed the card {before} to {card}" : "Sa oled muutnud kaardi nime: {before} → {card}",
     "{user} has renamed the card {before} to {card}" : "{user} on muutnud kaardi nime: {before} → {card}",
+    "You have added a description to card {card} in list {stack} on board {board}" : "Sa oled {board} tahvli {stack} loendi {card} kaardile lisanud kirjelduse",
     "You have marked the card {card} as done in list {stack} on board {board}" : "Sa oled märkinud {board} tahvli {stack} loendi {card} kaardi tehtuks",
     "{user} has marked card {card} as done in list {stack} on board {board}" : "{user} on märkinud {board} tahvli {stack} loendi {card} kaardi tehtuks",
     "You have marked the card {card} as undone in list {stack} on board {board}" : "Sa oled märkinud {board} tahvli {stack} loendi {card} kaardi mittetehtuks",
     "{user} has marked the card {card} as undone in list {stack} on board {board}" : "{user} on märkinud {board} tahvli {stack} loendi {card} kaardi mittetehtuks",
+    "You have removed the due date of card {card}" : "Sina oled eemaldanud „{card}“ kaardi tähtaja",
+    "{user} has removed the due date of card {card}" : "{user} on eemaldanud „{card}“ kaardi tähtaja",
+    "You have set the due date of card {card} to {after}" : "Sina oled määranud „{card}“ kaardi tähtajaks {after}",
+    "{user} has set the due date of card {card} to {after}" : "{user} on määranud „{card}“ kaardi tähtajaks {after}",
+    "You have updated the due date of card {card} to {after}" : "Sina oled muutnud „{card}“ kaardi tähtajaks {after}",
+    "{user} has updated the due date of card {card} to {after}" : "{user} on muutnud „{card}“ kaardi tähtajaks {after}",
+    "You have assigned {assigneduser} to card {card} on board {board}" : "Sa oled määranud {board} tahvli {card} kaardi täitjaks {assigneduser}",
+    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} on määranud {board} tahvli {card} kaardi täitjaks {assigneduser}",
+    "You have unassigned {assigneduser} from card {card} on board {board}" : "Sa oled {board} tahvli {card} kaardi täitja rollist eemaldanud kasutaja {assigneduser}",
+    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} on  {board} tahvli {card} kaardi täitja rollist eemaldanud kasutaja {assigneduser}",
+    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} on tõstnud {card} kaardi ühest loendist teise: {stackBefore} → {stack}",
+    "You have added the attachment {attachment} to card {card}" : "Sa oled lisanud „{card}“ kaardile „{attachment}“ manuse",
+    "{user} has added the attachment {attachment} to card {card}" : "{user} on lisanud „{card}“ kaardile „{attachment}“ manuse",
+    "You have updated the attachment {attachment} on card {card}" : "Sina oled uuendanud „{card}“ kaardil „{attachment}“ manust",
+    "{user} has updated the attachment {attachment} on card {card}" : "{user} on uuendanud „{card}“ kaardil „{attachment}“ manust",
+    "You have deleted the attachment {attachment} from card {card}" : "Sina oled kustutanud „{card}“ kaardilt „{attachment}“ manuse",
+    "{user} has deleted the attachment {attachment} from card {card}" : "{user} on kustutanud „{card}“ kaardilt „{attachment}“ manuse",
+    "You have restored the attachment {attachment} to card {card}" : "Sa oled taastanud „{card}“ kaardile „{attachment}“ manuse",
+    "{user} has restored the attachment {attachment} to card {card}" : "{user} on taastanud „{card}“ kaardi „{attachment}“ manuse",
+    "You have commented on card {card}" : "Sina oled kommenteerinud „{card}“ kaarti",
+    "{user} has commented on card {card}" : "{user} on kommenteerinud „{card}“ kaarti",
     "Deck" : "Deck",
     "Changes in the <strong>Deck app</strong>" : "Muudatused <strong>Kanbani rakenduses</strong>",
     "A <strong>board, list or card</strong> was changed" : "<strong>Tahvel, loend või kaart</strong> on muutunud",
@@ -64,9 +87,15 @@ OC.L10N.register(
     "Action needed" : "Tegevus on vajalik",
     "Later" : "Hiljem",
     "copy" : "koopia",
+    "Read more inside" : "Loe lisateavet järgnevast",
+    "Custom lists - click to rename!" : "Kohandatud loendid - klõpsi nime muutmiseks!",
     "To Do" : "Tegemiseks",
     "In Progress" : "Töös",
     "Done" : "Valmis",
+    "1. Open to learn more about boards and cards" : "1. Ava lugemaks lisateavet tahvlite ja kaartide kohta",
+    "2. Drag cards left and right, up and down" : "2. Lohista kaarte vasakule ja paremale ning üles ja alla",
+    "3. Apply rich formatting and link content" : "3. Kasuta teksti vormindamise ja linkide lisamise võimalust",
+    "4. Share, comment and collaborate!" : "4. Jaga, kommenteeri ning osale ühistegevuses!",
     "Create your first card!" : "Koosta oma esimene kaart!",
     "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "Sellel kommentaari pikkus on üle %s tähemärgi.\nTa on kaardile lisatud „%s“ nimega manusena.\nVõrguaadress: %s.",
     "Attachments" : "Manused",
@@ -201,7 +230,7 @@ OC.L10N.register(
     "Reply" : "Vasta",
     "Update" : "Uuenda",
     "Write a description …" : "Koosta kirjeldus…",
-    "Could not save description" : "Kirjelduse salvetamine ei õnnestunud",
+    "Could not save description" : "Kirjelduse salvestamine ei õnnestunud",
     "Description" : "Kirjeldus",
     "(Unsaved)" : "(Salvestamata)",
     "(Saving…)" : "(Salvestan…)",
@@ -319,9 +348,7 @@ OC.L10N.register(
     "Note: Only the JSON format is supported for importing back into the Deck app." : "Märkus: vaid JSON-vorming on toetatud tagasi importimiseks kanbani-rakendusse.",
     "Export" : "Ekspordi",
     "Loading filtered view" : "Laadin filtreeritud vaadet",
-    "Today" : "Täna",
-    "Tomorrow" : "Homme",
-    "No due" : "Tähtaega pole",
+    "Search for {searchQuery} in other boards" : "Otsi muudelt tahvlitelt: „{searchQuery}“",
     "Search for {searchQuery} in all boards" : "Otsi kõikidelt tahvlitelt: „{searchQuery}“",
     "No results found" : "Otsingutulemusi ei leidu",
     "Deck board {name}\n* Last modified on {lastMod}" : "Kanbani tahvel {name}\n* Viimati muudetud {lastMod}",
@@ -362,6 +389,9 @@ OC.L10N.register(
     "Example Task 3" : "Näidisülesanne 3",
     "Example Task 2" : "Näidisülesanne 2",
     "Example Task 1" : "Näidisülesanne 1",
-    "Move card to another board" : "Tõsta kaart teisele tahvlile"
+    "Move card to another board" : "Tõsta kaart teisele tahvlile",
+    "Today" : "Täna",
+    "Tomorrow" : "Homme",
+    "No due" : "Tähtaega pole"
 },
 "nplurals=2; plural=(n != 1);");
