@@ -212,8 +212,6 @@ OC.L10N.register(
     "Advanced options" : "Opsi lanjutan",
     "Clone" : "Klona",
     "Export" : "Ekspor",
-    "Today" : "Hari ini",
-    "Tomorrow" : "Besok",
     "Click to expand comment" : "Klik untuk membuka komentar",
     "Close" : "Tutup",
     "No upcoming cards" : "Tidak ada kartu berikut",
@@ -230,6 +228,8 @@ OC.L10N.register(
     "Example Task 3" : "Contoh tugas 3",
     "Example Task 2" : "Contoh tugas 2",
     "Example Task 1" : "Contoh tugas 1",
-    "Move card to another board" : "Pindahkan kartu ke papan lain"
+    "Move card to another board" : "Pindahkan kartu ke papan lain",
+    "Today" : "Hari ini",
+    "Tomorrow" : "Besok"
 },
 "nplurals=1; plural=0;");
