@@ -72,6 +72,15 @@ OC.L10N.register(
     "A <strong>board, list or card</strong> was changed" : "<strong>ボード、リストまたはカードは変更されました",
     "A <strong>comment</strong> was created on a card" : "カードに<strong>コメント</strong>が作成されたとき",
     "A <strong>card description</strong> has been changed" : "<strong>カード説明</strong>が変更されました",
+    "The file was uploaded" : "ファイルがアップロードされました",
+    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "アップロードされたファイルがphp.iniのupload_max_filesizeディレクティブを超えています",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "アップロードファイルはHTMLフォームで指定された MAX_FILE_SIZE の制限を超えています",
+    "The file was only partially uploaded" : "ファイルは一部分にしかアップロードされていません",
+    "No file was uploaded" : "ファイルはアップロードされませんでした",
+    "Missing a temporary folder" : "一時領域フォルダーがありません",
+    "Could not write file to disk" : "ディスクにファイルを書き込めませんでした",
+    "A PHP extension stopped the file upload" : "PHP拡張でファイルのアップロードが停止されています",
+    "No file uploaded or file size exceeds maximum of %s" : "ファイルがアップロードされていないか、ファイルサイズが最大 %s を超えています",
     "Cards due today" : "今日の期限切れのカード",
     "Cards due tomorrow" : "明日の期限切れのカード",
     "Upcoming cards" : "今後のカード",
@@ -101,16 +110,9 @@ OC.L10N.register(
     "To Do" : "To Do",
     "In Progress" : "進行中",
     "Done" : "完了",
-    "The file was uploaded" : "ファイルがアップロードされました",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "アップロードされたファイルがphp.iniのupload_max_filesizeディレクティブを超えています",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "アップロードファイルはHTMLフォームで指定された MAX_FILE_SIZE の制限を超えています",
-    "The file was only partially uploaded" : "ファイルは一部分にしかアップロードされていません",
-    "No file was uploaded" : "ファイルはアップロードされませんでした",
-    "Missing a temporary folder" : "一時領域フォルダーがありません",
-    "Could not write file to disk" : "ディスクにファイルを書き込めませんでした",
-    "A PHP extension stopped the file upload" : "PHP拡張でファイルのアップロードが停止されています",
-    "No file uploaded or file size exceeds maximum of %s" : "ファイルがアップロードされていないか、ファイルサイズが最大 %s を超えています",
     "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "このコメントは、%s 文字以上含まれています。\n%sという名前で、カードに添付ファイルとして追加しました。\n次のURLでアクセス可能です: %s",
+    "Attachments" : "添付ファイル",
+    "File" : "ファイル",
     "Card not found" : "カードが見つかりません",
     "Path is already shared with this card" : "パスは既にこのカードで共有されています",
     "Invalid date, date format must be YYYY-MM-DD" : "日付が無効です。日付形式はYYYY-MM-DDである必要があります",
@@ -226,7 +228,6 @@ OC.L10N.register(
     "The title cannot be empty." : "タイトルを空にすることはできません。",
     "Open in sidebar view" : "サイドバービューで開く",
     "Open in bigger view" : "拡大表示で開く",
-    "Attachments" : "添付ファイル",
     "Comments" : "コメント",
     "Failed to load comments" : "コメントの読み込みに失敗しました",
     "No comments yet. Begin the discussion!" : "まだコメントはありません。議論を始めましょう！",
@@ -273,6 +274,7 @@ OC.L10N.register(
     "{count} comments, {unread} unread" : "コメント {count} 件あり、 {unread} 件未読",
     "Todo items" : "Todo項目",
     "Edit card title" : "カードタイトルを編集する",
+    "Open link" : "リンクを開く",
     "Card deleted" : "カードが削除されました",
     "Edit title" : "タイトルを編集",
     "Assign to me" : "自分に割り当てる",
@@ -338,10 +340,9 @@ OC.L10N.register(
     "Clone cards" : "カードを複製",
     "Advanced options" : "詳細オプション",
     "Clone" : "複製",
+    "Export as CSV" : "CSV にエクスポート",
+    "Export" : "エクスポート",
     "Loading filtered view" : "フィルタされたビューを読み込み中",
-    "Today" : "今日",
-    "Tomorrow" : "明日",
-    "No due" : "日付なし",
     "Search for {searchQuery} in all boards" : "すべてのボードで{searchQuery}を検索します",
     "No results found" : "結果が見つかりません",
     "Deck board {name}\n* Last modified on {lastMod}" : "デッキボード{name}\n最終更新日：{lastMod}",
@@ -370,6 +371,7 @@ OC.L10N.register(
     "Something went wrong" : "何かがおかしいです",
     "Failed to upload {name}" : "{name}のアップロードに失敗しました",
     "Maximum file size of {size} exceeded" : "最大ファイルサイズ（{size}）を超えています",
+    "Due date" : "期限",
     "Error creating the share" : "共有の作成中にエラーが発生しました",
     "Share with a Deck card" : "デッキのカードで共有する",
     "Share {file} with a Deck card" : "{file}をデッキのカードで共有する",
@@ -381,6 +383,8 @@ OC.L10N.register(
     "Example Task 2" : "タスク2の例",
     "Example Task 1" : "タスク1の例",
     "Move card to another board" : "カードを他のボードに移動",
-    "Filter by completed" : "完成したものをフィルターする"
+    "Today" : "今日",
+    "Tomorrow" : "明日",
+    "No due" : "日付なし"
 },
 "nplurals=1; plural=0;");
