@@ -1,36 +1,44 @@
 OC.L10N.register(
     "deck",
     {
-    "Finished" : "Immed",
-    "Done" : "Immed",
     "The file was uploaded" : "Ulac afaylu yettwaznen",
     "The file was only partially uploaded" : "Afaylu, cwiṭ kan i yettwaznen segs",
     "No file was uploaded" : "Ulac afaylu i d-yettwasulin",
     "Missing a temporary folder" : "Ixuṣ ukaram akudan",
+    "Finished" : "Immed",
+    "copy" : "nɣel",
+    "Done" : "Immed",
+    "Attachments" : "Ticeqqufin",
+    "File" : "Afaylu",
     "Cancel" : "Sefsex",
     "Open" : "Ldi",
     "Completed" : "Yemmed",
+    "Open details" : "Ldi talqayt",
     "Details" : "Talqayt",
     "Sharing" : "Beṭṭu",
     "Tags" : "Tibzimin",
     "Activity" : "Armud",
+    "Transfer" : "Seḍfeṛ",
     "Owner" : "Bab",
     "Delete" : "Kkes",
     "Edit" : "Ẓreg",
     "Download" : "Sider",
-    "Attachments" : "Ticeqqufin",
-    "Comments" : "Commentaires",
     "Modified" : "Yettwabeddel",
     "Created" : "Yettwarna.",
+    "Comments" : "Commentaires",
     "Save" : "Sekles",
     "Cancel reply" : "Semmet tiririt.",
     "Reply" : "Err",
+    "Description" : "Aglam",
+    "Open link" : "Nɣel aseɣwen",
+    "Keyboard shortcuts" : "Inegzumen n unasiw",
+    "Ctrl" : "Ctrl",
     "Search" : "Nadi",
     "Cancel edit" : "Sefsex aseẓreg",
     "No notifications" : "Ulac tisezmal",
-    "Today" : "Ass-a",
     "Close" : "Mdel",
     "Share" : "Bḍu",
-    "Personal" : "Udmawan"
+    "Personal" : "Udmawan",
+    "Today" : "Ass-a"
 },
 "nplurals=2; plural=(n != 1);");
