@@ -3,6 +3,7 @@ OC.L10N.register(
     {
     "copy" : "ចម្លង",
     "Done" : "Done",
+    "File" : "ឯកសារ",
     "Cancel" : "បោះបង់",
     "Details" : "ព័ត៌មាន​លម្អិត",
     "Sharing" : "ការ​ចែក​រំលែក",
@@ -16,16 +17,17 @@ OC.L10N.register(
     "Download" : "ទាញយក",
     "Modified" : "បាន​កែ​ប្រែ",
     "Save" : "រក្សាទុក",
+    "Created:" : "បាន​បង្កើត៖",
     "Reply" : "ឆ្លើយតប",
     "Update" : "ធ្វើ​បច្ចុប្បន្នភាព",
-    "Created:" : "បាន​បង្កើត៖",
     "Description" : "ការ​អធិប្បាយ",
     "seconds ago" : "វិនាទី​មុន",
     "Search" : "ស្វែងរក",
     "Shared with you" : "Shared with you",
-    "Today" : "ថ្ងៃ​នេះ",
+    "Export" : "នាំចេញ",
     "Close" : "បិទ",
     "Share" : "ចែក​រំលែក",
-    "Personal" : "ផ្ទាល់​ខ្លួន"
+    "Personal" : "ផ្ទាល់​ខ្លួន",
+    "Today" : "ថ្ងៃ​នេះ"
 },
 "nplurals=1; plural=0;");
