@@ -1,19 +1,19 @@
 OC.L10N.register(
     "deck",
     {
-    "You have created a new board {board}" : "您创建了一个新面板{board}",
-    "{user} has created a new board {board}" : "{user} 创建了一个新面板{board}",
-    "You have deleted the board {board}" : "您删除了面板{board}",
-    "{user} has deleted the board {board}" : "{user}删除了面板{board}",
-    "You have restored the board {board}" : "您还原了面板{board}",
-    "{user} has restored the board {board}" : "{user}还原了{board}",
-    "You have shared the board {board} with {acl}" : "您已分享{board}给{acl}",
-    "{user} has shared the board {board} with {acl}" : "{user}已使用{acl}分享面板{board}",
-    "You have removed {acl} from the board {board}" : "您从面板{board}中移除了{acl}",
-    "{user} has removed {acl} from the board {board}" : "{user}从面板{board}中移除了{acl} ",
-    "You have renamed the board {before} to {board}" : "您将面板{before}重命名为{board}",
-    "{user} has renamed the board {before} to {board}" : "{user}将面板{before}重命名为{board}",
-    "You have archived the board {board}" : "您已将面板{board}归档",
+    "You have created a new board {board}" : "您创建了新面板 {board}",
+    "{user} has created a new board {board}" : "{user} 创建了新面板 {board}",
+    "You have deleted the board {board}" : "您删除了面板 {board}",
+    "{user} has deleted the board {board}" : "{user} 删除了面板 {board}",
+    "You have restored the board {board}" : "您还原了面板 {board}",
+    "{user} has restored the board {board}" : "{user} 还原了面板 {board}",
+    "You have shared the board {board} with {acl}" : "您已分享面板 {board} 给 {acl}",
+    "{user} has shared the board {board} with {acl}" : "{user}已使用 {acl} 分享了面板 {board}",
+    "You have removed {acl} from the board {board}" : "您从面板 {board} 中移除了 {acl}",
+    "{user} has removed {acl} from the board {board}" : "{user} 从面板 {board} 中移除了 {acl} ",
+    "You have renamed the board {before} to {board}" : "您将面板 {before} 重命名为 {board}",
+    "{user} has renamed the board {before} to {board}" : "{user} 将面板 {before} 重命名为 {board}",
+    "You have archived the board {board}" : "您已将面板 {board} 归档",
     "{user} has archived the board {before}" : "{user}已将面板{before}归档",
     "You have unarchived the board {board}" : "您已将面板{board}取消归档",
     "{user} has unarchived the board {before}" : "{user}已将面板{before}取消归档",
@@ -37,6 +37,10 @@ OC.L10N.register(
     "{user} has archived card {card} in list {stack} on board {board}" : "{user} 已对面板 {board} 上的列表 {stack} 中的卡片 {card} 执行归档",
     "You have unarchived card {card} in list {stack} on board {board}" : "您已对面板 {board} 上的列表 {stack} 中的卡片 {card} 撤销归档",
     "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} 已对面板 {board} 上的列表 {stack} 中的卡片 {card} 撤销归档",
+    "You have marked the card {card} as done in list {stack} on board {board}" : "您已在面板 {board} 上的列表 {stack} 中将卡片 {card} 标记为已完成",
+    "{user} has marked card {card} as done in list {stack} on board {board}" : "{user} 已在面板 {board} 上的列表 {stack} 中将卡片 {card} 标记为已完成",
+    "You have marked the card {card} as undone in list {stack} on board {board}" : "您已在面板 {board} 上的列表 {stack} 中将卡片 {card} 标记为未完成",
+    "{user} has marked the card {card} as undone in list {stack} on board {board}" : "{user} 已在面板 {board} 上的列表 {stack} 中将卡片 {card} 标记为未完成",
     "You have removed the due date of card {card}" : "您移除了卡片 {card} 的截止日期",
     "{user} has removed the due date of card {card}" : "{user} 移除了卡片 {card} 的截止日期",
     "You have set the due date of card {card} to {after}" : "您将卡片 {card} 的截止日期设置为 {after}",
@@ -68,9 +72,23 @@ OC.L10N.register(
     "A <strong>board, list or card</strong> was changed" : "<strong>面板、列表或卡片</strong>已更新",
     "A <strong>comment</strong> was created on a card" : "卡片上创建了一个 <strong>评论</strong>",
     "A <strong>card description</strong> has been changed" : "<strong>卡片描述</strong>已更新",
+    "The file was uploaded" : "文件已上传",
+    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上传文件的大小已超过 php.ini 中 upload_max_filesize 设置的值",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上传的文件长度超出了 HTML 表单中设定的 MAX_FILE_SIZE 上限",
+    "The file was only partially uploaded" : "文件仅部分上传",
+    "No file was uploaded" : "文件未被上传",
+    "Missing a temporary folder" : "缺少临时文件夹",
+    "Could not write file to disk" : "无法写入文件到磁盘",
+    "A PHP extension stopped the file upload" : "一个PHP扩展程序中断了文件上传。",
+    "No file uploaded or file size exceeds maximum of %s" : "没有文件被上传或文件大小超出最大值 %s",
+    "Invalid file type. Only JSON files are allowed." : "文件类型无效。只允许 JSON 文件。",
+    "Invalid JSON data" : "JSON 数据无效",
+    "Failed to import board" : "无法导入面板",
+    "Cards due today" : "今天到期的卡片",
+    "Cards due tomorrow" : "卡片明天到期",
     "Upcoming cards" : "即将到来的卡片",
     "Load more" : "加载更多",
-    "Personal" : "个人",
+    "Welcome to Nextcloud Deck!" : "欢迎使用 Nextcloud Deck！",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "卡片  \"%s\" （在 \"%s\" 中）已由%s指派给您。",
     "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} 已将卡片 {deck-card}， 其位于 {deck-board} ，分配给了你",
     "The card \"%s\" on \"%s\" has reached its due date." : "卡片 \"%s\" （在 \"%s\" 中）已到期.",
@@ -93,43 +111,47 @@ OC.L10N.register(
     "Action needed" : "需要操作",
     "Later" : "稍后",
     "copy" : "复制",
-    "To do" : "待办",
-    "Doing" : "进行中",
+    "Read more inside" : "阅读更多内容",
+    "Custom lists - click to rename!" : "自定义列表 - 单击以重命名！",
+    "To Do" : "待办",
+    "In Progress" : "进行中",
     "Done" : "完成",
-    "Example Task 3" : "示例任务 3",
-    "Example Task 2" : "示例任务 2",
-    "Example Task 1" : "示例任务 1",
-    "The file was uploaded" : "文件已上传",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上传文件的大小已超过 php.ini 中 upload_max_filesize 设置的值",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上传的文件长度超出了 HTML 表单中设定的 MAX_FILE_SIZE 上限",
-    "The file was only partially uploaded" : "文件仅部分上传",
-    "No file was uploaded" : "文件未被上传",
-    "Missing a temporary folder" : "缺少临时文件夹",
-    "Could not write file to disk" : "无法写入文件到磁盘",
-    "A PHP extension stopped the file upload" : "一个PHP扩展程序中断了文件上传。",
-    "No file uploaded or file size exceeds maximum of %s" : "没有文件被上传或文件大小超出最大值 %s",
+    "1. Open to learn more about boards and cards" : "1. 打开以了解更多关于面板和卡片的信息",
+    "2. Drag cards left and right, up and down" : "2. 左右上下拖动卡片",
+    "3. Apply rich formatting and link content" : "3. 应用丰富的格式和链接内容",
+    "4. Share, comment and collaborate!" : "4. 分享、评论和协作！",
+    "Create your first card!" : "创建您的第一张卡片！",
     "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "此评论超过%s个字符。\n作为附件添加到名称为 %s 的卡片上。\n可通过 URL  访问：%s。",
+    "Attachments" : "附件",
+    "File" : "文件",
+    "date" : "日期",
     "Card not found" : "未找到卡片",
     "Path is already shared with this card" : "已和这张卡片分享了路径",
     "Invalid date, date format must be YYYY-MM-DD" : "无效日期，日期格式必须为 YYYY-MM-DD",
     "Personal planning and team project organization" : "个人规划和团队项目安排",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "看板应用程序是一个看板风格的管理工具，旨在为与Nextcloud集成的团队进行个人规划和项目管理。\n\n\n- 📥 添加您的任务到卡片并将之整理好\n- 📄 用Markdown写下额外的注释\n- 🔖 分配标签以更好地管理您的工作\n- 👥 与您的团队、朋友或家人分享\n- 📎 附件文件并将其嵌入到您的Markdown描述中\n- 💬 使用评论与您的团队沟通\n- ⚡ 在活动流中跟踪变更情况\n- 🚀 让您的项目井井有条",
     "Add board" : "添加面板",
+    "Card details" : "卡片详情",
     "Select the board to link to a project" : "选择要链接到一个项目的面板",
     "Search by board title" : "通过标题搜索面板",
     "Select board" : "选择面板",
+    "Move/copy card" : "移动/复制卡片",
     "Select a board" : "选择一个面板",
-    "Select a card" : "选择一张卡片",
-    "Cancel" : "取消",
+    "No lists available" : "无列表可用",
+    "Select a list" : "选择一个列表",
+    "Move card" : "移动卡片",
+    "Copy card" : "复制卡片",
     "Select the card to link to a project" : "选择要链接到一个项目的卡片",
     "Link to card" : "链接到卡片",
+    "Select a card" : "选择一张卡片",
+    "Cancel" : "取消",
+    "This board is read only" : "此面板是只读的",
+    "Drop your files to upload" : "拖放您的文件以上传",
     "File already exists" : "文件已存在",
     "A file with the name {filename} already exists." : "使用文件名 {filename} 的文件已存在。",
     "Do you want to overwrite it?" : "您确定要覆盖吗？",
     "Overwrite file" : "覆盖文件",
     "Keep existing file" : "保持已存在的文件",
-    "This board is read only" : "此面板是只读的",
-    "Drop your files to upload" : "拖放您的文件以上传",
     "Add card" : "添加卡片",
     "Archived cards" : "已归档卡片",
     "Add list" : "添加列表",
@@ -139,6 +161,10 @@ OC.L10N.register(
     "Filter by tag" : "按标签筛选",
     "Filter by assigned user" : "按指派的用户筛选",
     "Unassigned" : "未指派",
+    "Filter by status" : "按状态筛选",
+    "Open and completed" : "打开并完成",
+    "Open" : "打开",
+    "Completed" : "已完成",
     "Filter by due date" : "按截止日期筛选",
     "Overdue" : "逾期",
     "Next 24 hours" : "未来24小时",
@@ -146,16 +172,19 @@ OC.L10N.register(
     "Next 30 days" : "未来30天",
     "No due date" : "无截止日期",
     "Clear filter" : "清除筛选",
+    "View Modes" : "视图模式",
+    "Toggle View Modes" : "切换视图模式",
     "Hide archived cards" : "隐藏已归档卡片",
     "Show archived cards" : "显示已归档卡片",
     "Toggle compact mode" : "切换简洁模式",
+    "Hide card cover images" : "隐藏卡片封面图片",
+    "Show card cover images" : "显示卡片封面图片",
     "Open details" : "打开详情",
     "Details" : "详情",
     "Currently present people" : "当前在线的人",
     "Loading board" : "正在加载面板",
-    "No lists available" : "无列表可用",
-    "Create a new list to add cards to this board" : "创建新列表后，即可在面板中新建卡片",
     "Board not found" : "未找到面板",
+    "Create a new list to add cards to this board" : "创建新列表后，即可在面板中新建卡片",
     "Sharing" : "正在共享",
     "Tags" : "标签",
     "Deleted items" : "已删除项",
@@ -163,23 +192,24 @@ OC.L10N.register(
     "Deleted lists" : "已删除的列表",
     "Undo" : "撤消",
     "Deleted cards" : "已删除的卡片",
-    "Share board with a user, group or circle …" : "与一个用户，群组或圈子共享面板...",
-    "Searching for users, groups and circles …" : "正在搜索用户、群组和圈子 ......",
-    "No participants found" : "未找到参与者",
-    "Board owner" : "面板拥有者",
-    "(Group)" : "（群组）",
-    "(Circle)" : "（圈子）",
-    "Can edit" : "可以编辑",
-    "Can share" : "可以共享",
-    "Can manage" : "可以管理",
-    "Owner" : "所有者",
-    "Delete" : "删除",
     "Failed to create share with {displayName}" : "用{displayName}创建分享失败",
     "Are you sure you want to transfer the board {title} to {user}?" : "您确定要将面板 {title} 转移到 {user} 吗？",
     "Transfer the board." : "转移面板。",
     "Transfer" : "转移",
     "The board has been transferred to {user}" : "面板已转移给 {user}",
     "Failed to transfer the board to {user}" : "未能将面板转移给 {user}",
+    "Share board with a user, group or team …" : "与用户、群组或团队分享面板…",
+    "Searching for users, groups and teams …" : "搜索用户、群组和团队…",
+    "No participants found" : "未找到参与者",
+    "Board owner" : "面板所有者",
+    "(Group)" : "（群组）",
+    "(Team)" : "（团队）",
+    "Can edit" : "可以编辑",
+    "Can share" : "可以共享",
+    "Can manage" : "可以管理",
+    "Owner" : "所有者",
+    "Delete" : "删除",
+    "List deleted" : "列表被删除",
     "Edit list title" : "编辑列表标题",
     "Archive all cards" : "归档所有卡片",
     "Unarchive all cards" : "取消归档所有卡片",
@@ -188,14 +218,16 @@ OC.L10N.register(
     "Unarchive all cards in this list" : "取消归档所有此列表中的卡片",
     "Add a new card" : "添加一张新卡片",
     "Card name" : "卡片名",
-    "List deleted" : "列表被删除",
-    "Edit" : "编辑",
-    "Add a new tag" : "新增一个标签",
     "title and color value must be provided" : "必须提供标题和颜色值",
+    "Edit" : "编辑",
+    "Add a new tag" : "添加新标签",
     "Board name" : "面板名称",
     "Members" : "成员",
-    "Assign to users/groups/circles" : "指派给用户/群组/圈子",
+    "Assign to users/groups/team" : "分配给用户/群组/团队",
     "Assign a user to this card…" : "为该卡片指派用户…",
+    "Select a user to assign to this card…" : "选择要分配给此卡片的用户…",
+    "File to share" : "要分享的文件",
+    "Invalid path selected" : "选择的路径无效",
     "Upload new files" : "上传新文件",
     "Share from Files" : "从文件共享",
     "Pending share" : "待分享",
@@ -205,25 +237,25 @@ OC.L10N.register(
     "Remove attachment" : "删除附件",
     "Delete Attachment" : "删除附件",
     "Restore Attachment" : "恢复附件",
-    "File to share" : "要分享的文件",
-    "Invalid path selected" : "选择的路径无效",
-    "Open in sidebar view" : "在侧边栏视图中打开",
-    "Open in bigger view" : "在较大视图中打开",
-    "Attachments" : "附件",
-    "Comments" : "评论",
     "Modified" : "已修改",
     "Created" : "已创建",
     "The title cannot be empty." : "标题不能为空",
-    "No comments yet. Begin the discussion!" : "还没有评论。 开始讨论吧！",
+    "Cannot close unsaved card!" : "无法关闭未保存的卡片！",
+    "Open in sidebar view" : "在侧边栏视图中打开",
+    "Open in bigger view" : "在较大视图中打开",
+    "Comments" : "评论",
     "Failed to load comments" : "加载评论失败",
-    "Save" : "保存",
+    "No comments yet. Begin the discussion!" : "还没有评论。 开始讨论吧！",
     "The comment cannot be empty." : "注释不能为空。",
     "The comment cannot be longer than 1000 characters." : "注释不能超过 1000 个字符。",
+    "Save" : "保存",
+    "Created:" : "创建于：",
     "In reply to" : "回复",
     "Cancel reply" : "取消回复",
     "Reply" : "回复",
     "Update" : "更新",
-    "Created:" : "创建于：",
+    "Write a description …" : "写一段描述",
+    "Could not save description" : "无法保存描述",
     "Description" : "描述",
     "(Unsaved)" : "（未保存的）",
     "(Saving…)" : "（正在保存...）",
@@ -231,33 +263,67 @@ OC.L10N.register(
     "Edit description" : "编辑描述",
     "View description" : "查看描述",
     "Add Attachment" : "添加附件",
-    "Write a description …" : "写一段描述",
     "Choose attachment" : "选择附件",
+    "Select Date" : "选择日期",
+    "Later today – {timeLocale}" : "今日稍晚 – {timeLocale}",
+    "Set due date for later today" : "将截止日期设置为今天晚些时候",
+    "Tomorrow – {timeLocale}" : "明天 – {timeLocale}",
+    "Set due date for tomorrow" : "设定明天的截止日期",
+    "This weekend – {timeLocale}" : "本周末 – {timeLocale}",
+    "Set due date for this weekend" : "设置本周末的截止日期",
+    "Next week – {timeLocale}" : "下周 – {timeLocale}",
+    "Set due date for next week" : "设置下周的截止日期",
     "Assign a due date to this card…" : "为此卡片指派截止日期 …",
     "Set a due date" : "设置截止日期",
+    "Add due date" : "添加截止日期",
+    "Choose a date" : "选择日期",
     "Remove due date" : "移除截止日期",
-    "Completed" : "已完成",
-    "Not completed" : "没完成",
+    "Mark as done" : "标记为已完成",
+    "Due at:" : "到期日：",
+    "Not done" : "未完成",
     "Unarchive card" : "撤销对卡片的归档",
     "Archive card" : "归档卡片",
-    "Select Date" : "选择日期",
-    "Assign a tag to this card…" : "为该卡片分配标签…",
+    "Assign a tag to this card…" : "为此卡片分配标签…",
+    "Select or create a tag…" : "选择或创建标签…",
+    "Create a new tag:" : "创建新标签：",
     "(group)" : "（组）",
-    "Next week – {timeLocale}" : "下周 – {timeLocale}",
-    "Todo items" : "待办事项",
     "{count} comments, {unread} unread" : "{count} 条评论，{unread} 未读",
+    "Todo items" : "待办事项",
     "Edit card title" : "编辑卡片标题",
-    "Card details" : "卡片详情",
+    "Open link" : "打开链接",
+    "Card deleted" : "卡片被删除",
+    "Edit title" : "编辑标题",
     "Assign to me" : "指派给我",
     "Unassign myself" : "不再指派给我",
-    "Mark as done" : "标记为已完成",
-    "Move card" : "移动卡片",
+    "Mark as not done" : "标记为未完成",
     "Delete card" : "删除卡片",
-    "Move card to another board" : "将卡片移到其他面板",
-    "Select a list" : "选择一个列表",
-    "List is empty" : "列表为空",
-    "Card deleted" : "卡片被删除",
     "seconds ago" : "几秒前",
+    "Keyboard shortcuts" : "键盘快捷键",
+    "Boost your productivity using Deck with keyboard shortcuts." : "使用带有键盘快捷键的 Deck 提高您的生产力。",
+    "Board actions" : "面板操作",
+    "Keyboard shortcut" : "键盘快捷键",
+    "Action" : "操作",
+    "Shift" : "Shift",
+    "Scroll" : "滚动",
+    "Scroll sideways" : "侧向滚动",
+    "Navigate between cards" : "在卡片之间导航",
+    "Esc" : "Esc",
+    "Close card details" : "关闭卡详细信息",
+    "Ctrl" : "Ctrl",
+    "Search" : "搜索",
+    "Show card filters" : "显示卡片过滤器",
+    "Clear card filters" : "清除卡片过滤器",
+    "Show help dialog" : "显示帮助对话框",
+    "Card actions" : "卡片操作",
+    "The following actions can be triggered on the currently highlighted card" : "可以在当前突出显示的卡上触发以下操作",
+    "Enter" : "输入",
+    "Space" : "空间",
+    "Open card details" : "打开卡片详细信息",
+    "Edit the card title" : "编辑卡片标题",
+    "Assign yourself to the current card" : "将自己分配给当前卡片",
+    "Archive/unarchive the current card" : "存档/取消存档当前卡片",
+    "Mark card as completed/not completed" : "将卡片标记为已完成/未完成",
+    "Open card menu" : "打开卡片菜单",
     "All boards" : "全部面板",
     "Archived boards" : "已归档面板",
     "Shared with you" : "收到的共享",
@@ -265,6 +331,18 @@ OC.L10N.register(
     "Use bigger card view" : "使用较大的卡片视图",
     "Show card ID badge" : "显示卡片ID序号",
     "Show boards in calendar/tasks" : "在日历/任务中显示看板",
+    "Limit board creation to some groups" : "限制某些组可以创建看板",
+    "Users outside of those groups will not be able to create their own boards, but will still be able to work on boards that have been shared with them." : "这些组之外的用户将无法创建自己的看板，但仍然可以在与他们共享的看板上工作。",
+    "Cancel edit" : "取消编辑",
+    "Save board" : "保存面板",
+    "Board {0} deleted" : "面板{0} 被删除",
+    "All cards" : "所有卡片",
+    "Only assigned cards" : "仅限已指派的卡片",
+    "No reminder" : "无提醒",
+    "An error occurred" : "发生错误",
+    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "您确定要删除面板 {title} 吗？这将删除该面板的所有数据，包括已归档卡片。",
+    "Delete the board?" : "是否删除面板？",
+    "Exporting board..." : "正在导出面板…",
     "Board details" : "面板详情",
     "Edit board" : "编辑面板",
     "Clone board" : "克隆面板",
@@ -274,42 +352,49 @@ OC.L10N.register(
     "Turn on due date reminders" : "打开截止日期提醒",
     "Turn off due date reminders" : "关闭截止日期提醒",
     "Due date reminders" : "截止日期提醒",
-    "All cards" : "所有卡片",
     "Assigned cards" : "已指派的卡片",
     "No notifications" : "无通知",
     "Delete board" : "删除看板",
-    "Board {0} deleted" : "面板{0} 被删除",
-    "Only assigned cards" : "仅限已指派的卡片",
-    "No reminder" : "无提醒",
-    "An error occurred" : "发生错误",
-    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "您确定要删除面板 {title} 吗？这将删除该面板的所有数据，包括已归档卡片。",
-    "Delete the board?" : "是否删除面板？",
+    "Importing board..." : "正在导入面板…",
+    "Board imported successfully" : "面板导入成功",
+    "Import board" : "导入面板",
+    "Clone {boardTitle}" : "克隆 {boardTitle}",
+    "Clone cards" : "克隆卡片",
+    "Clone assignments" : "克隆任务",
+    "Clone labels" : "克隆标签",
+    "Clone due dates" : "克隆到期日",
+    "Advanced options" : "高级选项",
+    "Move all cards to the first list" : "将所有卡片移至第一个列表",
+    "Restore archived cards" : "恢复已存档的卡片",
+    "Clone" : "克隆",
+    "Export {boardTitle}" : "导出 {boardTitle}",
+    "Export as JSON" : "导出为 JSON",
+    "Export as CSV" : "导出为 CSV",
+    "Note: Only the JSON format is supported for importing back into the Deck app." : "注意：只有 JSON 格式才支持导入回 Deck 应用。",
+    "Export" : "导出",
     "Loading filtered view" : "正在加载已筛选的视图",
-    "Today" : "今天",
-    "Tomorrow" : "明天",
-    "No due" : "没有到期的",
+    "Search for {searchQuery} in other boards" : "在其他面板中搜索 {searchQuery}",
     "Search for {searchQuery} in all boards" : "在所有看板中搜索 {searchQuery}",
     "No results found" : "未找到结果",
-    "This weekend – {timeLocale}" : "本周末 – {timeLocale}",
     "Deck board {name}\n* Last modified on {lastMod}" : "看板{name}\n* 最后修改于{lastMod}",
-    "{stack} in {board}" : "{stack} 于 {board}",
-    "Click to expand description" : "点击展开描述",
     "* Created on {created}\n* Last modified on {lastMod}\n* {nbAttachments} attachments\n* {nbComments} comments" : "* 创建于 {created}\n* 最后修改于 {lastMod}\n* {nbAttachments} 个附件\n* {nbComments} 个评论",
     "{nbCards} cards" : "{nbCards} 张卡片",
+    "Due on {date}" : "于 {date} 到期 ",
+    "{stack} in {board}" : "{stack} 于 {board}",
+    "Click to expand description" : "点击展开描述",
     "Click to expand comment" : "点击展开评论",
+    "Create card" : "创建卡片",
     "Create a new card" : "创建一张新卡片",
     "Card title" : "卡片标题",
-    "Create card" : "创建卡片",
     "Creating the new card …" : "正在创建新卡片… ",
     "Card \"{card}\" was added to \"{board}\"" : "卡片 \"{card}\" 被添加至看板 \"{board}\"",
     "Open card" : "打开卡片",
     "Close" : "关闭",
     "No upcoming cards" : "没有即将到来的卡片",
+    "upcoming cards today" : "今天即将推出的卡片",
+    "upcoming cards tomorrow" : "明天即将推出的卡片",
     "upcoming cards" : "即将到来的卡片",
     "New card" : "新卡片",
-    "Due on {date}" : "于 {date} 到期 ",
-    "Tomorrow – {timeLocale}" : "明天 – {timeLocale}",
-    "Later today – {timeLocale}" : "今日稍晚 – {timeLocale}",
     "Link to a board" : "链接到一个面板",
     "Link to a card" : "链接到一张卡片",
     "Create a card" : "创建一张卡片",
@@ -317,18 +402,21 @@ OC.L10N.register(
     "Something went wrong" : "发生了错误",
     "Failed to upload {name}" : "未能上传{name}",
     "Maximum file size of {size} exceeded" : "文件容量已超过 {size} 的上限",
+    "Assigned users" : "已指派的用户",
+    "Due date" : "截止日期",
     "Error creating the share" : "创建分享出错",
     "Share with a Deck card" : "分享给一张看板卡片",
     "Share {file} with a Deck card" : "将{file}分享给一张看板卡片",
     "Share" : "分享",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "看板应用中的 <strong>卡片描述</strong> 已改变",
-    "Timeline" : "时间线",
-    "Add a new list" : "添加新列表",
-    "Assign to users" : "指派给用户",
-    "Due date" : "截止日期",
-    "Next week" : "下周",
-    "Next month" : "下月",
-    "Limit deck usage of groups" : "按群组限制看板的使用权",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "限制看板的使用权后，不在指定群组中的用户将不能新建面板，但仍可使用已共享给他们的面板。"
+    "Personal" : "个人",
+    "To do" : "待办",
+    "Doing" : "进行中",
+    "Example Task 3" : "示例任务 3",
+    "Example Task 2" : "示例任务 2",
+    "Example Task 1" : "示例任务 1",
+    "Move card to another board" : "将卡片移到其他面板",
+    "Today" : "今天",
+    "Tomorrow" : "明天",
+    "No due" : "没有到期的"
 },
 "nplurals=1; plural=0;");
