@@ -72,11 +72,23 @@ OC.L10N.register(
     "A <strong>board, list or card</strong> was changed" : "<strong>面板、清單或卡片</strong>已更新",
     "A <strong>comment</strong> was created on a card" : "卡片上創建了一個 <strong>意見</strong>",
     "A <strong>card description</strong> has been changed" : "<strong>卡片描述</strong>已更新",
+    "The file was uploaded" : "檔案已上傳",
+    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上傳的檔案大小超過 php.ini 當中 upload_max_filesize 選項的限制",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 的限制",
+    "The file was only partially uploaded" : "檔案僅部分上傳",
+    "No file was uploaded" : "沒有檔案被上傳",
+    "Missing a temporary folder" : "找不到暫存資料夾",
+    "Could not write file to disk" : "無法將檔案寫入磁碟",
+    "A PHP extension stopped the file upload" : "某個 PHP 擴充功能終止檔案的上傳",
+    "No file uploaded or file size exceeds maximum of %s" : "沒有上傳檔案或檔案大小超過 %s 的最大值",
+    "Invalid file type. Only JSON files are allowed." : "無效的檔案類型。僅允許 JSON 檔案。",
+    "Invalid JSON data" : "無效的 JSON 數據",
+    "Failed to import board" : "無法導入面板",
     "Cards due today" : "於今日到期的卡片",
     "Cards due tomorrow" : "於明日到期的卡片",
     "Upcoming cards" : "快將到期的卡片",
     "Load more" : "載入更多",
-    "Personal" : "個人",
+    "Welcome to Nextcloud Deck!" : "歡迎來到 Nextcloud Deck！",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "%s 已將 “%s” 中的卡片 “%s” 指派給您。",
     "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} 已將 {deck-board} 中的卡片 {deck-card} 指派給您。",
     "The card \"%s\" on \"%s\" has reached its due date." : "\"%s\" 中的卡片 \"%s\" 已到期。",
@@ -99,48 +111,47 @@ OC.L10N.register(
     "Action needed" : "需要採取行動",
     "Later" : "稍後處理",
     "copy" : "複製",
-    "To do" : "待辦",
-    "Doing" : "執行中",
+    "Read more inside" : "您可以在裡面深入了解更多",
+    "Custom lists - click to rename!" : "自定義清單 - 點擊以重新命名！",
+    "To Do" : "待辦",
+    "In Progress" : "進行中",
     "Done" : "完成",
-    "Example Task 3" : "示例任務 3",
-    "Example Task 2" : "示例任務 2",
-    "Example Task 1" : "示例任務 1",
-    "The file was uploaded" : "檔案已上傳",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上傳的檔案大小超過 php.ini 當中 upload_max_filesize 選項的限制",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 的限制",
-    "The file was only partially uploaded" : "檔案僅部分上傳",
-    "No file was uploaded" : "沒有檔案被上傳",
-    "Missing a temporary folder" : "找不到暫存資料夾",
-    "Could not write file to disk" : "無法將檔案寫入磁碟",
-    "A PHP extension stopped the file upload" : "某個 PHP 擴充功能終止檔案的上傳",
-    "No file uploaded or file size exceeds maximum of %s" : "沒有上傳檔案或檔案大小超過 %s 的最大值",
+    "1. Open to learn more about boards and cards" : "1. 打開以了解更多有關面板和卡片的信息",
+    "2. Drag cards left and right, up and down" : "2. 拖動卡片向左和向右、向上和向下",
+    "3. Apply rich formatting and link content" : "3. 應用豐富的格式和連結內容",
+    "4. Share, comment and collaborate!" : "4. 分享、評論和協作！",
+    "Create your first card!" : "創建您的第一張卡片！",
     "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "此評論超過%s個字符。\n作為附件添加到名稱為 %s 的卡片上。\n可於此 URL  存取：%s。",
+    "Attachments" : "附件",
+    "File" : "檔案",
+    "date" : "日期",
     "Card not found" : "未找到卡片",
     "Path is already shared with this card" : "已和這張卡片分享了路徑",
     "Invalid date, date format must be YYYY-MM-DD" : "無效的日期，需為 YYYY-MM-DD 格式",
     "Personal planning and team project organization" : "個人規劃和團隊項目組織",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck是一種看板式組織工具，旨在針對與Nextcloud集成的團隊進行個人計劃和項目組織。\n\n\n- 📥 添加您的任務到 card 及將之整理好\n- 📄 用 Markdown 寫下額外的註釋分享分享分享\n- 🔖 分配標籤以更好地組織您的工作\n- 👥 與您的團隊、朋友或家人分享\n- 📎 附加檔案並將其嵌入到您的 Markdown 描述中 \n- 💬 使用意見與您的團隊討論\n- ⚡ 在活動流中跟踪更改\n- 🚀 讓您的專案井井有條",
-    "Card details" : "卡片詳情",
     "Add board" : "添加面板",
+    "Card details" : "卡片詳情",
     "Select the board to link to a project" : "選擇要連結到一個項目的面板",
     "Search by board title" : "通過標題搜索面板",
     "Select board" : "選擇面板",
-    "Move card to another board" : "將卡片移到其他面板",
+    "Move/copy card" : "移動/複製卡片",
     "Select a board" : "選擇一個面板",
     "No lists available" : "無清單可用",
     "Select a list" : "選擇一個列表",
     "Move card" : "移動卡片",
-    "Cancel" : "取消",
-    "Select a card" : "選擇卡片",
+    "Copy card" : "複製卡片",
     "Select the card to link to a project" : "選擇要連結到一個項目的卡片",
     "Link to card" : "連結到卡片",
+    "Select a card" : "選擇卡片",
+    "Cancel" : "取消",
+    "This board is read only" : "此面板是唯讀的",
+    "Drop your files to upload" : "拖放您的檔案以上傳",
     "File already exists" : "檔案已存在",
     "A file with the name {filename} already exists." : "名稱為 {filename} 的檔案已存在。",
     "Do you want to overwrite it?" : "您確定要覆蓋嗎？",
     "Overwrite file" : "覆蓋檔案",
     "Keep existing file" : "保持已存在的檔案",
-    "This board is read only" : "此面板是唯讀的",
-    "Drop your files to upload" : "拖放您的檔案以上傳",
     "Add card" : "添加卡片",
     "Archived cards" : "已存檔卡片",
     "Add list" : "添加清單",
@@ -181,6 +192,12 @@ OC.L10N.register(
     "Deleted lists" : "已刪除的清單",
     "Undo" : "撤消",
     "Deleted cards" : "已刪除卡片",
+    "Failed to create share with {displayName}" : "無法為 {displayName} 創建分享",
+    "Are you sure you want to transfer the board {title} to {user}?" : "您確定要將面板 {title} 轉讓給 {user} 嗎？",
+    "Transfer the board." : "轉移面板。",
+    "Transfer" : "轉移",
+    "The board has been transferred to {user}" : "面板已轉讓給 {user}",
+    "Failed to transfer the board to {user}" : "未能將面板轉移給 {user}",
     "Share board with a user, group or team …" : "與用戶、群組或團隊分享面板 …",
     "Searching for users, groups and teams …" : "搜尋使用者、群組與團隊 …",
     "No participants found" : "未找到參與者",
@@ -192,12 +209,7 @@ OC.L10N.register(
     "Can manage" : "可以管理",
     "Owner" : "所有者",
     "Delete" : "刪除",
-    "Failed to create share with {displayName}" : "無法為 {displayName} 創建分享",
-    "Are you sure you want to transfer the board {title} to {user}?" : "您確定要將面板 {title} 轉讓給 {user} 嗎？",
-    "Transfer the board." : "轉移面板。",
-    "Transfer" : "轉移",
-    "The board has been transferred to {user}" : "面板已轉讓給 {user}",
-    "Failed to transfer the board to {user}" : "未能將面板轉移給 {user}",
+    "List deleted" : "清單已被刪除",
     "Edit list title" : "編輯清單標題",
     "Archive all cards" : "封存所有卡片",
     "Unarchive all cards" : "解除封存所有卡片",
@@ -206,15 +218,16 @@ OC.L10N.register(
     "Unarchive all cards in this list" : "解除封存所有此列表中的卡片",
     "Add a new card" : "添加一張新卡片",
     "Card name" : "卡片名稱",
-    "List deleted" : "清單已被刪除",
+    "title and color value must be provided" : "必須提供標題和顏色值",
     "Edit" : "編輯",
     "Add a new tag" : "添加新標籤",
-    "title and color value must be provided" : "必須提供標題和顏色值",
     "Board name" : "面板名",
     "Members" : "成員",
     "Assign to users/groups/team" : "分配給用戶／群組／團隊",
     "Assign a user to this card…" : "將此卡片指派給用戶...",
     "Select a user to assign to this card…" : "選擇一個用戶賦值給此卡片...",
+    "File to share" : "要分享的檔案",
+    "Invalid path selected" : "選中了無效的路徑",
     "Upload new files" : "上傳新檔案",
     "Share from Files" : "從檔案進行分享",
     "Pending share" : "等待分享",
@@ -224,25 +237,25 @@ OC.L10N.register(
     "Remove attachment" : "移除附件",
     "Delete Attachment" : "刪除附件",
     "Restore Attachment" : "恢復附件",
-    "File to share" : "要分享的檔案",
-    "Invalid path selected" : "選中了無效的路徑",
-    "Open in sidebar view" : "在側邊欄視圖中打開",
-    "Open in bigger view" : "在較大視圖中打開",
-    "Attachments" : "附件",
-    "Comments" : "意見",
     "Modified" : "修改於",
     "Created" : "建立於",
     "The title cannot be empty." : "標題不能為空。",
-    "No comments yet. Begin the discussion!" : "尚無意見，開始討論吧！",
+    "Cannot close unsaved card!" : "無法關閉無法儲存的卡片！",
+    "Open in sidebar view" : "在側邊欄視圖中打開",
+    "Open in bigger view" : "在較大視圖中打開",
+    "Comments" : "意見",
     "Failed to load comments" : "無法加載評論",
-    "Save" : "保存",
+    "No comments yet. Begin the discussion!" : "尚無意見，開始討論吧！",
     "The comment cannot be empty." : "意見不能為空。",
     "The comment cannot be longer than 1000 characters." : "意見不能超過 1000 個字符。",
+    "Save" : "保存",
+    "Created:" : "建立：",
     "In reply to" : "回覆",
     "Cancel reply" : "取消回覆",
     "Reply" : "回覆",
     "Update" : "更新",
-    "Created:" : "建立：",
+    "Write a description …" : "寫一段描述",
+    "Could not save description" : "無法保存描述",
     "Description" : "描述",
     "(Unsaved)" : "（未保存的）",
     "(Saving…)" : "（保存中...）",
@@ -250,8 +263,16 @@ OC.L10N.register(
     "Edit description" : "編輯描述",
     "View description" : "查看描述",
     "Add Attachment" : "添加附件",
-    "Write a description …" : "寫一段描述",
     "Choose attachment" : "選擇附件",
+    "Select Date" : "選擇日期",
+    "Later today – {timeLocale}" : "今天稍後 – {timeLocale}",
+    "Set due date for later today" : "設定今天稍後的到期日",
+    "Tomorrow – {timeLocale}" : "明天 – {timeLocale}",
+    "Set due date for tomorrow" : "設定明天的到期日",
+    "This weekend – {timeLocale}" : "本週末 – {timeLocale}",
+    "Set due date for this weekend" : "設定本週末的到期日",
+    "Next week – {timeLocale}" : "下星期 – {timeLocale}",
+    "Set due date for next week" : "設定下星期的到期日",
     "Assign a due date to this card…" : "為此卡片指派到期日 …",
     "Set a due date" : "設置到期日",
     "Add due date" : "添加到期日",
@@ -262,24 +283,20 @@ OC.L10N.register(
     "Not done" : "未完成",
     "Unarchive card" : "取消對卡片的封存",
     "Archive card" : "封存卡片",
-    "Select Date" : "選擇日期",
-    "Set due date for later today" : "設定今天稍後的到期日",
-    "Set due date for tomorrow" : "設定明天的到期日",
-    "Set due date for this weekend" : "設定本週末的到期日",
-    "Set due date for next week" : "設定下星期的到期日",
     "Assign a tag to this card…" : "為該卡片分配標籤…",
     "Select or create a tag…" : "選擇或創建標籤 ...",
     "Create a new tag:" : "創建新標籤：",
     "(group)" : "（群組）",
-    "Next week – {timeLocale}" : "下星期 – {timeLocale}",
-    "Todo items" : "待辦事項",
     "{count} comments, {unread} unread" : "{count} 條評論，{unread} 條未讀",
+    "Todo items" : "待辦事項",
     "Edit card title" : "編輯卡片標題",
+    "Open link" : "打開連結",
+    "Card deleted" : "卡片被刪除",
+    "Edit title" : "編輯標題",
     "Assign to me" : "指派給我",
     "Unassign myself" : "自己解除指派",
     "Mark as not done" : "標記為未完成",
     "Delete card" : "刪除卡片",
-    "Card deleted" : "卡片被刪除",
     "seconds ago" : "幾秒前",
     "Keyboard shortcuts" : "鍵盤快捷鍵",
     "Boost your productivity using Deck with keyboard shortcuts." : "提高您的生產力，在 Deck 上使用鍵盤快捷鍵。",
@@ -318,6 +335,14 @@ OC.L10N.register(
     "Users outside of those groups will not be able to create their own boards, but will still be able to work on boards that have been shared with them." : "這些群組之外的用戶將無法創建自己的面板，但仍然可以在與他們共享的面板上工作。",
     "Cancel edit" : "取消編輯",
     "Save board" : "保存面板",
+    "Board {0} deleted" : "面板 {0} 已被刪除",
+    "All cards" : "所有卡片",
+    "Only assigned cards" : "僅指派了的卡片",
+    "No reminder" : "無提醒",
+    "An error occurred" : "發生錯誤",
+    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "你確定你要刪除 {title} 面板嗎？面板內所有數據(包括已封存的卡片)都將因此被刪除。",
+    "Delete the board?" : "是否刪除面板？",
+    "Exporting board..." : "正在導出面板 ...",
     "Board details" : "面板詳情",
     "Edit board" : "編輯面板",
     "Clone board" : "複製面板",
@@ -327,31 +352,40 @@ OC.L10N.register(
     "Turn on due date reminders" : "開啟到期日提醒",
     "Turn off due date reminders" : "關閉到期日提醒",
     "Due date reminders" : "到期日提醒",
-    "All cards" : "所有卡片",
     "Assigned cards" : "分配的卡片",
     "No notifications" : "無通知",
     "Delete board" : "刪除面板",
-    "Board {0} deleted" : "面板 {0} 已被刪除",
-    "Only assigned cards" : "僅指派了的卡片",
-    "No reminder" : "無提醒",
-    "An error occurred" : "發生錯誤",
-    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "你確定你要刪除 {title} 面板嗎？面板內所有數據(包括已封存的卡片)都將因此被刪除。",
-    "Delete the board?" : "是否刪除面板？",
+    "Importing board..." : "正在導入面板 ...",
+    "Board imported successfully" : "面板成功導入",
+    "Import board" : "導入面板",
+    "Clone {boardTitle}" : "複製 {boardTitle}",
+    "Clone cards" : "複製 cards",
+    "Clone assignments" : "複製任務分配",
+    "Clone labels" : "複製標籤",
+    "Clone due dates" : "複製期日期",
+    "Advanced options" : "進階選項",
+    "Move all cards to the first list" : "將所有卡片移動到第一個清單",
+    "Restore archived cards" : "還原已封存的卡片",
+    "Clone" : "複製",
+    "Export {boardTitle}" : "導出 {boardTitle}",
+    "Export as JSON" : "導出為 JSON",
+    "Export as CSV" : "匯出為 CSV",
+    "Note: Only the JSON format is supported for importing back into the Deck app." : "注意：僅支援 JSON 格式以便重新導入到 Deck 應用程式。",
+    "Export" : "導出",
     "Loading filtered view" : "正在加載已過濾視圖",
-    "Today" : "今日",
-    "Tomorrow" : "明日",
-    "No due" : "沒有到期的",
+    "Search for {searchQuery} in other boards" : "在其他看板中搜尋 {searchQuery}",
     "Search for {searchQuery} in all boards" : "在所有面板中搜索 {searchQuery}",
     "No results found" : "未找到結果",
     "Deck board {name}\n* Last modified on {lastMod}" : "Deck 面板 {name}\n* 最後修改於  {lastMod}",
-    "{stack} in {board}" : "{board} 中的 {stack}",
-    "Click to expand description" : "點擊展開描述",
     "* Created on {created}\n* Last modified on {lastMod}\n* {nbAttachments} attachments\n* {nbComments} comments" : "* 創建於 {created}\n* 最後修改於 {lastMod}\n* {nbAttachments} 個附件\n* {nbComments} 則留言",
     "{nbCards} cards" : "{nbCards} 張卡片",
+    "Due on {date}" : "於 {date} 到期",
+    "{stack} in {board}" : "{board} 中的 {stack}",
+    "Click to expand description" : "點擊展開描述",
     "Click to expand comment" : "點擊展開評論",
+    "Create card" : "建立卡片",
     "Create a new card" : "建立新卡片",
     "Card title" : "卡片標題",
-    "Create card" : "建立卡片",
     "Creating the new card …" : "正在建立新卡片...",
     "Card \"{card}\" was added to \"{board}\"" : "\"{card}\" 已添加到 \"{board}\"",
     "Open card" : "打開卡片",
@@ -361,24 +395,28 @@ OC.L10N.register(
     "upcoming cards tomorrow" : "明天接下來的卡片",
     "upcoming cards" : "快將到期的卡片",
     "New card" : "新卡片",
-    "Due on {date}" : "於 {date} 到期",
-    "This weekend – {timeLocale}" : "本週末 – {timeLocale}",
-    "Tomorrow – {timeLocale}" : "明天 – {timeLocale}",
-    "Later today – {timeLocale}" : "今天稍後 – {timeLocale}",
     "Link to a board" : "連結到面板",
     "Link to a card" : "連結到卡片",
     "Create a card" : "建立卡片",
     "Message from {author} in {conversationName}" : "來自 {conversationName} 中的 {author} 之消息",
     "Something went wrong" : "發生錯誤了",
     "Failed to upload {name}" : "上傳 {name} 失敗",
-    "Maximum file size of {size} exceeded" : "文件大小 {size} 超出最大限制",
+    "Maximum file size of {size} exceeded" : "檔案大小 {size} 超出最大限制",
+    "Assigned users" : "指派的用戶",
+    "Due date" : "到期日期",
     "Error creating the share" : "創建分享出錯",
     "Share with a Deck card" : "用一張 Deck 卡片進行分享 ",
     "Share {file} with a Deck card" : "用一張 Deck 卡片分享 {file}",
     "Share" : "分享",
-    "Searching for users, groups and circles …" : "正在搜尋用戶、群組和圈子 ......",
-    "(Circle)" : "（圈子）",
-    "Assign to users/groups/circles" : "指派給用戶/群組/圈子",
-    "Filter by completed" : "按已完成篩選"
+    "Personal" : "個人",
+    "To do" : "待辦",
+    "Doing" : "執行中",
+    "Example Task 3" : "示例任務 3",
+    "Example Task 2" : "示例任務 2",
+    "Example Task 1" : "示例任務 1",
+    "Move card to another board" : "將卡片移到其他面板",
+    "Today" : "今日",
+    "Tomorrow" : "明日",
+    "No due" : "沒有到期的"
 },
 "nplurals=1; plural=0;");
