@@ -1,24 +1,8 @@
 <?php
+
 /**
- * @copyright Copyright (c) 2016 Julius Härtl <jus@bitgrid.net>
- *
- * @author Julius Härtl <jus@bitgrid.net>
- *
- * @license GNU AGPL version 3 or any later version
- *
- *  This program is free software: you can redistribute it and/or modify
- *  it under the terms of the GNU Affero General Public License as
- *  published by the Free Software Foundation, either version 3 of the
- *  License, or (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Affero General Public License for more details.
- *
- *  You should have received a copy of the GNU Affero General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2016 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Deck\Db;
@@ -62,7 +46,7 @@ class CardMapper extends QBMapper implements IPermissionMapper {
 		IManager $notificationManager,
 		ICacheFactory $cacheFactory,
 		$databaseType = 'sqlite3',
-		$database4ByteSupport = true
+		$database4ByteSupport = true,
 	) {
 		parent::__construct($db, 'deck_cards', Card::class);
 		$this->labelMapper = $labelMapper;
@@ -130,7 +114,7 @@ class CardMapper extends QBMapper implements IPermissionMapper {
 		return parent::update($cardUpdate);
 	}
 
-	public function find($id): Card {
+	public function find($id, bool $enhance = true): Card {
 		$qb = $this->db->getQueryBuilder();
 		$qb->select('*')
 			->from('deck_cards')
@@ -139,9 +123,11 @@ class CardMapper extends QBMapper implements IPermissionMapper {
 			->addOrderBy('id');
 		/** @var Card $card */
 		$card = $this->findEntity($qb);
-		$labels = $this->labelMapper->findAssignedLabelsForCard($card->getId());
-		$card->setLabels($labels);
-		$this->mapOwner($card);
+		if ($enhance) {
+			$labels = $this->labelMapper->findAssignedLabelsForCard($card->getId());
+			$card->setLabels($labels);
+			$this->mapOwner($card);
+		}
 		return $card;
 	}
 
@@ -171,7 +157,7 @@ class CardMapper extends QBMapper implements IPermissionMapper {
 
 	public function queryCardsByBoards(array $boardIds): IQueryBuilder {
 		$qb = $this->db->getQueryBuilder();
-		$qb->select('c.*')
+		$qb->selectDistinct('c.*')
 			->from('deck_cards', 'c')
 			->innerJoin('c', 'deck_stacks', 's', $qb->expr()->eq('s.id', 'c.stack_id'))
 			->andWhere($qb->expr()->in('s.board_id', $qb->createNamedParameter($boardIds, IQueryBuilder::PARAM_INT_ARRAY)));
@@ -263,6 +249,7 @@ class CardMapper extends QBMapper implements IPermissionMapper {
 			->where($qb->expr()->in('s.board_id', $qb->createNamedParameter($boardIds, IQueryBuilder::PARAM_INT_ARRAY)))
 			->andWhere($qb->expr()->isNotNull('c.duedate'))
 			->andWhere($qb->expr()->eq('c.archived', $qb->createNamedParameter(false, IQueryBuilder::PARAM_BOOL)))
+			->andWhere($qb->expr()->isNull('done'))
 			->andWhere($qb->expr()->eq('c.deleted_at', $qb->createNamedParameter(0, IQueryBuilder::PARAM_INT)))
 			->andWhere($qb->expr()->eq('s.deleted_at', $qb->createNamedParameter(0, IQueryBuilder::PARAM_INT)))
 			->andWhere($qb->expr()->eq('b.archived', $qb->createNamedParameter(false, IQueryBuilder::PARAM_BOOL)))
@@ -284,6 +271,7 @@ class CardMapper extends QBMapper implements IPermissionMapper {
 			)
 			// Filter out archived/deleted cards and board
 			->andWhere($qb->expr()->eq('c.archived', $qb->createNamedParameter(false, IQueryBuilder::PARAM_BOOL)))
+			->andWhere($qb->expr()->isNull('done'))
 			->andWhere($qb->expr()->eq('c.deleted_at', $qb->createNamedParameter(0, IQueryBuilder::PARAM_INT)))
 			->andWhere($qb->expr()->eq('s.deleted_at', $qb->createNamedParameter(0, IQueryBuilder::PARAM_INT)))
 			->andWhere($qb->expr()->eq('b.archived', $qb->createNamedParameter(false, IQueryBuilder::PARAM_BOOL)))
@@ -298,6 +286,7 @@ class CardMapper extends QBMapper implements IPermissionMapper {
 			->where($qb->expr()->lt('duedate', $qb->createFunction('NOW()')))
 			->andWhere($qb->expr()->eq('notified', $qb->createNamedParameter(false, IQueryBuilder::PARAM_BOOL)))
 			->andWhere($qb->expr()->eq('archived', $qb->createNamedParameter(false, IQueryBuilder::PARAM_BOOL)))
+			->andWhere($qb->expr()->isNull('done'))
 			->andWhere($qb->expr()->eq('deleted_at', $qb->createNamedParameter(0, IQueryBuilder::PARAM_INT)));
 		return $this->findEntities($qb);
 	}
@@ -310,7 +299,7 @@ class CardMapper extends QBMapper implements IPermissionMapper {
 		return $this->findEntities($qb);
 	}
 
-	public function search(array $boardIds, SearchQuery $query, int $limit = null, int $offset = null): array {
+	public function search(array $boardIds, SearchQuery $query, ?int $limit = null, ?int $offset = null): array {
 		$qb = $this->queryCardsByBoards($boardIds);
 		$this->extendQueryByFilter($qb, $query);
 
@@ -336,7 +325,6 @@ class CardMapper extends QBMapper implements IPermissionMapper {
 			);
 		}
 
-		$qb->groupBy('c.id');
 		$qb->orderBy('c.last_modified', 'DESC');
 		if ($limit !== null) {
 			$qb->setMaxResults($limit);
@@ -354,7 +342,7 @@ class CardMapper extends QBMapper implements IPermissionMapper {
 		return $entities;
 	}
 
-	public function searchComments(array $boardIds, SearchQuery $query, int $limit = null, int $offset = null): array {
+	public function searchComments(array $boardIds, SearchQuery $query, ?int $limit = null, ?int $offset = null): array {
 		if (count($query->getTextTokens()) === 0) {
 			return [];
 		}
@@ -380,7 +368,6 @@ class CardMapper extends QBMapper implements IPermissionMapper {
 			$tokenMatching
 		);
 
-		$qb->groupBy('comments.id', 'c.id');
 		$qb->orderBy('comments.id', 'DESC');
 		if ($limit !== null) {
 			$qb->setMaxResults($limit);
@@ -416,7 +403,7 @@ class CardMapper extends QBMapper implements IPermissionMapper {
 		if (count($query->getTag())) {
 			foreach ($query->getTag() as $index => $tag) {
 				$qb->innerJoin('c', 'deck_assigned_labels', 'al' . $index, $qb->expr()->eq('c.id', 'al' . $index . '.card_id'));
-				$qb->innerJoin('al'. $index, 'deck_labels', 'l' . $index, $qb->expr()->eq('al' . $index . '.label_id', 'l' . $index . '.id'));
+				$qb->innerJoin('al' . $index, 'deck_labels', 'l' . $index, $qb->expr()->eq('al' . $index . '.label_id', 'l' . $index . '.id'));
 				$qb->andWhere($qb->expr()->iLike('l' . $index . '.title', $qb->createNamedParameter('%' . $this->db->escapeLikeParameter($tag->getValue()) . '%', IQueryBuilder::PARAM_STR)));
 			}
 		}
@@ -424,7 +411,7 @@ class CardMapper extends QBMapper implements IPermissionMapper {
 		foreach ($query->getDuedate() as $duedate) {
 			$dueDateColumn = $this->databaseType === 'sqlite3' ? $qb->createFunction('DATETIME(`c`.`duedate`)') : 'c.duedate';
 			$date = $duedate->getValue();
-			if ($date === "") {
+			if ($date === '') {
 				$qb->andWhere($qb->expr()->isNotNull('c.duedate'));
 				continue;
 			}
@@ -475,7 +462,7 @@ class CardMapper extends QBMapper implements IPermissionMapper {
 			foreach ($query->getAssigned() as $index => $assignment) {
 				$qb->innerJoin('c', 'deck_assigned_users', 'au' . $index, $qb->expr()->eq('c.id', 'au' . $index . '.card_id'));
 				$assignedQueryValue = $assignment->getValue();
-				if ($assignedQueryValue === "") {
+				if ($assignedQueryValue === '') {
 					$qb->andWhere($qb->expr()->isNotNull('au' . $index . '.participant'));
 					continue;
 				}
@@ -576,12 +563,15 @@ class CardMapper extends QBMapper implements IPermissionMapper {
 	}
 
 	public function isOwner($userId, $id): bool {
-		$sql = 'SELECT owner FROM `*PREFIX*deck_boards` WHERE `id` IN (SELECT board_id FROM `*PREFIX*deck_stacks` WHERE id IN (SELECT stack_id FROM `*PREFIX*deck_cards` WHERE id = ?))';
-		$stmt = $this->db->prepare($sql);
-		$stmt->bindParam(1, $id, \PDO::PARAM_INT, 0);
-		$stmt->execute();
-		$row = $stmt->fetch();
-		return ($row['owner'] === $userId);
+		$qb = $this->db->getQueryBuilder();
+		$qb->select('c.id')
+			->from($this->getTableName(), 'c')
+			->innerJoin('c', 'deck_stacks', 's', 'c.stack_id = s.id')
+			->innerJoin('s', 'deck_boards', 'b', 'b.id = s.board_id')
+			->where($qb->expr()->eq('c.id', $qb->createNamedParameter($id, IQueryBuilder::PARAM_INT)))
+			->andWhere($qb->expr()->eq('b.owner', $qb->createNamedParameter($userId, IQueryBuilder::PARAM_STR)));
+
+		return count($qb->executeQuery()->fetchAll()) > 0;
 	}
 
 	public function findBoardId($id): ?int {
@@ -600,7 +590,7 @@ class CardMapper extends QBMapper implements IPermissionMapper {
 			}
 			$this->cache->set('findBoardId:' . $id, $result);
 		}
-		return $result !== false ? (int) $result : null;
+		return $result !== false ? (int)$result : null;
 	}
 
 	public function mapOwner(Card &$card) {
@@ -613,7 +603,7 @@ class CardMapper extends QBMapper implements IPermissionMapper {
 		});
 	}
 
-	public function transferOwnership(string $ownerId, string $newOwnerId, int $boardId = null): void {
+	public function transferOwnership(string $ownerId, string $newOwnerId, ?int $boardId = null): void {
 		$params = [
 			'owner' => $ownerId,
 			'newOwner' => $newOwnerId
@@ -655,4 +645,16 @@ class CardMapper extends QBMapper implements IPermissionMapper {
 
 		$result->closeCursor();
 	}
+
+	public function getAllCardIds(): array {
+		$qb = $this->db->getQueryBuilder();
+		$qb->select('id')
+			->from('deck_cards');
+		$result = $qb->executeQuery();
+		$ids = [];
+		while ($row = $result->fetch()) {
+			$ids[] = (int)$row['id'];
+		}
+		return $ids;
+	}
 }
